==> edge-login-ui-rn-3.4.1.tgz: package/lib/components/abSpecific/PinKeypad.js <==
import * as React from 'react';
import { TouchableWithoutFeedback, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import MaterialIcon from 'react-native-vector-icons/MaterialIcons';
import { lstrings } from '../../common/locales/strings';
import { useTheme } from '../services/ThemeContext';
import { PinButton } from '../themed/PinButton';
export function PinKeypad(props) {
    const { disabled, onPress } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(View, { style: styles.keypadContainer },
        React.createElement(View, { style: styles.keypadInner },
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_one, onPress: () => onPress('1') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_two, onPress: () => onPress('2') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_three, onPress: () => onPress('3') }))),
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_four, onPress: () => onPress('4') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_five, onPress: () => onPress('5') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_six, onPress: () => onPress('6') }))),
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_seven, onPress: () => onPress('7') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_eight, onPress: () => onPress('8') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_nine, onPress: () => onPress('9') }))),
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadColumnBlank }),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_zero, onPress: () => onPress('0') })),
                React.createElement(TouchableWithoutFeedback, { onPress: () => onPress('back'), disabled: disabled },
                    React.createElement(View, { style: styles.keypadColumnBack },
                        React.createElement(MaterialIcon, { name: "backspace", style: styles.keypadKeysBack })))))));
}
const getStyles = cacheStyles((theme) => ({
    keypadContainer: {
        width: '100%',
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center'
    },
    keypadInner: {
        flex: 1,
        maxWidth: theme.rem(22),
        height: theme.rem(13),
        maxHeight: theme.rem(19)
    },
    keypadRow: {
        flex: 1,
        flexDirection: 'row'
    },
    keypadBox: {
        flex: 1,
        margin: theme.rem(0.125),
        // borderColor: 'red',
        // borderWidth: 0.5,
        justifyContent: 'center',
        alignItems: 'center'
    },
    keypadColumnBack: {
        flex: 1,
        margin: theme.rem(0.125),
        justifyContent: 'center',
        alignItems: 'center'
    },
    keypadColumnBlank: {
        flex: 1,
        margin: theme.rem(0.125)
    },
    keypadKeysBack: {
        textAlign: 'center',
        fontSize: theme.rem(2),
        color: theme.secondaryButtonOutline
    }
}));

==> edge-login-ui-rn-3.17.0.tgz: package/lib/components/abSpecific/PinKeypad.js <==
import * as React from 'react';
import { View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import MaterialIcon from 'react-native-vector-icons/MaterialIcons';
import { lstrings } from '../../common/locales/strings';
import { EdgeTouchableWithoutFeedback } from '../common/EdgeTouchableWithoutFeedback';
import { useTheme } from '../services/ThemeContext';
import { PinButton } from '../themed/PinButton';
export function PinKeypad(props) {
    const { disabled, onPress } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(View, { style: styles.keypadContainer },
        React.createElement(View, { style: styles.keypadInner },
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_one, onPress: () => onPress('1') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_two, onPress: () => onPress('2') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_three, onPress: () => onPress('3') }))),
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_four, onPress: () => onPress('4') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_five, onPress: () => onPress('5') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_six, onPress: () => onPress('6') }))),
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_seven, onPress: () => onPress('7') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_eight, onPress: () => onPress('8') })),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_nine, onPress: () => onPress('9') }))),
            React.createElement(View, { style: styles.keypadRow },
                React.createElement(View, { style: styles.keypadColumnBlank }),
                React.createElement(View, { style: styles.keypadBox },
                    React.createElement(PinButton, { label: lstrings.keypad_zero, onPress: () => onPress('0') })),
                React.createElement(EdgeTouchableWithoutFeedback, { onPress: () => onPress('back'), disabled: disabled },
                    React.createElement(View, { style: styles.keypadColumnBack },
                        React.createElement(MaterialIcon, { name: "backspace", style: styles.keypadKeysBack })))))));
}
const getStyles = cacheStyles((theme) => ({
    keypadContainer: {
        width: '100%',
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center'
    },
    keypadInner: {
        flex: 1,
        maxWidth: theme.rem(22),
        height: theme.rem(13),
        maxHeight: theme.rem(19)
    },
    keypadRow: {
        flex: 1,
        flexDirection: 'row'
    },
    keypadBox: {
        flex: 1,
        margin: theme.rem(0.125),
        // borderColor: 'red',
        // borderWidth: 0.5,
        justifyContent: 'center',
        alignItems: 'center'
    },
    keypadColumnBack: {
        flex: 1,
        margin: theme.rem(0.125),
        justifyContent: 'center',
        alignItems: 'center'
    },
    keypadColumnBlank: {
        flex: 1,
        margin: theme.rem(0.125)
    },
    keypadKeysBack: {
        textAlign: 'center',
        fontSize: theme.rem(2),
        color: theme.secondaryButtonOutline
    }
}));
